@@ -162,7 +162,7 @@ int docmd_comb(arg_struct *arg) {
     if (reg_x->type == TYPE_REAL && reg_y->type == TYPE_REAL) {
         phloat y = ((vartype_real *) reg_y)->x;
         phloat x = ((vartype_real *) reg_x)->x;
-        phloat r = 1, q = 1;
+        phloat r, s, q = 1;
         vartype *v;
         if (x < 0 || x != floor(x) || x == x - 1 || y < 0 || y != floor(y))
             return ERR_INVALID_DATA;
@@ -170,6 +170,12 @@ int docmd_comb(arg_struct *arg) {
             return ERR_INVALID_DATA;
         if (x > y / 2)
             x = y - x;
+        #ifdef BCD_MATH
+            s = x == 0 ? 1 : pow(10, 1 + floor(log10(x)));
+        #else
+            s = x == 0 ? 1 : pow(2, 1 + floor(log2(x)));
+        #endif
+        r = 1 / s;
         while (q <= x) {
             r *= y--;
             if (p_isinf(r)) {
@@ -181,6 +187,13 @@ int docmd_comb(arg_struct *arg) {
             }
             r /= q++;
         }
+        r *= s;
+        if (p_isinf(r)) {
+            if (flags.f.range_error_ignore)
+                r = POS_HUGE_PHLOAT;
+            else
+                return ERR_OUT_OF_RANGE;
+        }
         v = new_real(r);
         if (v == NULL)
             return ERR_INSUFFICIENT_MEMORY;
@@ -375,7 +388,7 @@ int docmd_rtn(arg_struct *arg) {
         bool stop;
         pop_rtn_addr(&newprgm, &newpc, &stop);
         if (newprgm == -3)
-            return return_to_integ(0, stop);
+            return return_to_integ(stop);
         else if (newprgm == -2)
             return return_to_solve(0, stop);
         else if (newprgm == -1) {
@@ -636,7 +649,7 @@ static int generic_loop_helper(phloat *x, bool isg) {
      * This way is computationally cheaper, anyway.
      */
     if (isg) {
-        if (*x < 0 && *x > -k)
+        if (*x < 0 && floor(-(*x)) <= k)
             *x = -(*x) + k - 2 * i;
         else
             *x += k;
@@ -718,7 +731,9 @@ static int generic_loop(arg_struct *arg, bool isg) {
         }
         case ARGTYPE_STR: {
             vartype *v = recall_var(arg->val.text, arg->length);
-            if (v->type == TYPE_REAL)
+            if (v == NULL)
+                return ERR_NONEXISTENT;
+            else if (v->type == TYPE_REAL)
                 return generic_loop_helper(&((vartype_real *) v)->x, isg);
             else if (v->type == TYPE_STRING)
                 return ERR_ALPHA_DATA_IS_INVALID;
@@ -957,6 +972,7 @@ int docmd_varmenu(arg_struct *arg) {
 
 int docmd_getkey(arg_struct *arg) {
     mode_getkey = true;
+    mode_disable_stack_lift = flags.f.stack_lift_disable;
     return ERR_NONE;
 }
 
